pub struct CtPivotCache {
pub cache_id: u32,
pub id: String,
}Fields
cache_id: u32id: StringTrait Implementations
Sourceimpl Debug for CtPivotCache
impl Debug for CtPivotCache
Sourceimpl XmlDeserialize for CtPivotCache
impl XmlDeserialize for CtPivotCache
fn deserialize<B>(
tag: &[u8],
reader: &mut Reader<B>,
attrs: Attributes<'_>,
is_empty: bool,
) -> CtPivotCachewhere
B: BufRead,
fn de_root() -> Option<&'static [u8]>
A helper function used when ty =
untag. It could help
us to find out the children tags when deserializingSourcefn __deserialize_from_unparsed_array(
_array: Vec<(&'static [u8], Unparsed)>,
) -> Self
fn __deserialize_from_unparsed_array( _array: Vec<(&'static [u8], Unparsed)>, ) -> Self
A helper function used when handling the untag types. Read more
fn __deserialize_from_text(_: &str) -> Option<Self>where
Self: Sized,